##  Adding SAP LeanIX Store Templates to the Workspace
To add the survey templates from the SAP LeanIX store, do the following:
  1. From the workspace menu, select Store.
![Adding SAP LeanIX Store Templates to the Workspace](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275485af7a441014bda79ba0e1913e78_LowRes.png)
Adding SAP LeanIX Store Templates to the Workspace
  2. In the SAP LeanIX store, navigate to the Surveys section.
  3. Select the survey to add and click Add to Workspace.
